dixon.test(x, type = 0, opposite = FALSE, two.sided = TRUE)htest containing the following components:qdixon and qtable.
According to Dixon (1951) conclusions, the critical values can be obtained numerically only for n=3.
Other critical values are obtained by simulations, taken from original Dixon's paper, and
regarding corrections given by Rorabacher (1991).chisq.out.test, grubbs.testset.seed(1234)
x = rnorm(10)
dixon.test(x)
dixon.test(x,opposite=TRUE)
dixon.test(x,type=10)Run the code above in your browser using DataLab