"z" calculates normal scores (differences between each value and the mean
divided by sd), "t" calculates t-Student scores (transformed by (z*sqrt(n-2))/sqrt(z-1-t^2)
formula, "chisq" gives chi-squared scores (squares of differences between
prob
If set, the corresponding p-values instead of scores are given. If value is set
to 1, p-value are returned. Otherwise, a logical vector is formed, indicating which values are
exceeding specified probability. In "z" and "mad" types, there is also possibi
lim
This value can be set for "iqr" type of scores, to form logical vector, which values
has this limit exceeded.
Value
A vector of scores, probabilities, or logical vector.
References
Schiffler, R.E (1998). Maximum Z scores and outliers. Am. Stat. 42, 1, 79-80.